#!/bin/bash
#/////////////////////////////////////////////////////////////////////////
#//
#// (c) University of Southampton IT Innovation Centre, 2017
#//
#// Copyright in this software belongs to University of Southampton
#// IT Innovation Centre of Gamma House, Enterprise Road,
#// Chilworth Science Park, Southampton, SO16 7NS, UK.
#//
#// This software may not be used, sold, licensed, transferred, copied
#// or reproduced in whole or in part in any manner or form or in or
#// on any media by any person other than in accordance with the terms
#// of the Licence Agreement supplied with the software, or otherwise
#// without the prior written consent of the copyright owners.
#//
#// This software is distributed WITHOUT ANY WARRANTY, without even the
#// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#// PURPOSE, except where stated in the Licence Agreement supplied with
#// the software.
#//
#//      Created By :            Michael Boniface
#//      Created Date :          01/02/2018
#//      Created for Project :   FLAME
#//
#/////////////////////////////////////////////////////////////////////////

# Install nginx
apt-get update
yes Y | apt-get install nginx 

# Need to set up basic stats as this not configured by default
# http://nginx.org/en/docs/http/ngx_http_stub_status_module.html

NGINX_CONF_SOURCE=$REPO_ROOT"/clmctest/services/nginx/nginx.conf"
NGINX_CONF_TARGET="/etc/nginx/nginx.conf"

# Check the target telegraf directory exists
if [ ! -f "$NGINX_CONF_SOURCE" ]; then
    echo "Error: NGINX conf file does not exist on in the repo. "$NGINX_CONF_SOURCE
    exit 1
fi

cp -rf $NGINX_CONF_SOURCE $NGINX_CONF_TARGET

# Check the target telegraf directory exists
if [ ! -f "$NGINX_CONF_TARGET" ]; then
    echo "Error: NGINX conf copy failed to target machine. "$NGINX_CONF_TARGET
    exit 1
fi

nginx -s reload
systemctl start nginx

## install a configuration monitoring service, this needs to be in a venv with the rest of the CLMC
sudo apt-get install python3 python3-pip -y
sudo pip3 install pyaml influxdb

svc="nginxmon"

echo "install systemctl monitoring service"
svc_file="${svc}.service"
echo "[Unit]" > $svc_file
echo "Description=nginxmon" >> $svc_file
echo "After=network-online.target" >> $svc_file
echo "" >> $svc_file
echo "[Service]" >> $svc_file
echo "WorkingDirectory=${inst}/${dir}" >> $svc_file
echo "ExecStart=/usr/bin/python3 ${REPO_ROOT}/src/monitoring/systemctl_monitor.py -service nginx -rate 2 -agg 10 -host localhost -port 8186 -db CLMCMetrics" >> $svc_file
echo "ExecStop=/usr/bin/bash ${REPO_ROOT}/src/monitoring/stop_systemctl_monitor.sh" >> $svc_file
echo "" >> $svc_file
echo "[Install]" >> $svc_file
echo "WantedBy=network-online.target" >> $svc_file
sudo cp $svc_file /lib/systemd/system
rm $svc_file

echo "enable"
sudo systemctl daemon-reload
sudo systemctl enable ${svc}

echo "start"
sudo systemctl start ${svc}